@@ -95,6 +95,7 @@ void AttributeTest::testSerialization()
         QCOMPARE(to, a->to());
         QCOMPARE(cc, a->cc());
         QCOMPARE(bcc, a->bcc());
+        delete a;
     }
 
     {
@@ -112,6 +113,7 @@ void AttributeTest::testSerialization()
         a->deserialize(data);
         QCOMPARE(mode, a->dispatchMode());
         QCOMPARE(date, a->sendAfter());
+        delete a;
     }
 
     {
@@ -122,6 +124,7 @@ void AttributeTest::testSerialization()
         a = new ErrorAttribute;
         a->deserialize(data);
         QCOMPARE(msg, a->message());
+        delete a;
     }
 
     {
@@ -144,21 +147,95 @@ void AttributeTest::testSerialization()
 
         QCOMPARE(SentActionAttribute::Action::MarkAsForwarded, actions[1].type());
         QCOMPARE(id, actions[1].value().toLongLong());
+        delete a;
     }
 
     {
         SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::MoveToCollection;
         Collection::Id id = 123456789012345ll;
         SentBehaviourAttribute *a = new SentBehaviourAttribute(beh, Collection(id));
+        bool sendSilently = true;
+        a->setSendSilently(sendSilently);
         QByteArray data = a->serialized();
         delete a;
         a = new SentBehaviourAttribute;
         a->deserialize(data);
         QCOMPARE(beh, a->sentBehaviour());
         QCOMPARE(id, a->moveToCollection().id());
+        QCOMPARE(sendSilently, a->sendSilently());
         delete a;
     }
 
+    //MoveToCollection + silently
+    {
+        SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::MoveToCollection;
+        Collection::Id id = 123456789012345ll;
+        SentBehaviourAttribute *a = new SentBehaviourAttribute(beh, Collection(id));
+        bool sendSilently = true;
+        a->setSendSilently(sendSilently);
+        QByteArray data = a->serialized();
+        delete a;
+        a = new SentBehaviourAttribute;
+        a->deserialize(data);
+        QCOMPARE(beh, a->sentBehaviour());
+        QCOMPARE(id, a->moveToCollection().id());
+        QCOMPARE(sendSilently, a->sendSilently());
+        SentBehaviourAttribute *copy = a->clone();
+        QCOMPARE(copy->sentBehaviour(), beh);
+        QCOMPARE(copy->moveToCollection().id(), id);
+        QCOMPARE(copy->sendSilently(), sendSilently);
+        delete a;
+        delete copy;
+    }
+
+    //Delete + silently
+    {
+        SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::Delete;
+        Collection::Id id = 123456789012345ll;
+        SentBehaviourAttribute *a = new SentBehaviourAttribute(beh, Collection(id));
+        bool sendSilently = true;
+        a->setSendSilently(sendSilently);
+        QByteArray data = a->serialized();
+        delete a;
+        a = new SentBehaviourAttribute;
+        a->deserialize(data);
+        QCOMPARE(beh, a->sentBehaviour());
+        //When delete we move to -1
+        QCOMPARE(a->moveToCollection().id(), -1);
+        QCOMPARE(sendSilently, a->sendSilently());
+        SentBehaviourAttribute *copy = a->clone();
+        QCOMPARE(copy->sentBehaviour(), beh);
+        //When delete we move to -1
+        QCOMPARE(copy->moveToCollection().id(), -1);
+        QCOMPARE(copy->sendSilently(), sendSilently);
+        delete a;
+        delete copy;
+    }
+
+    //MoveToDefaultSentCollection + silently
+    {
+        SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::MoveToDefaultSentCollection;
+        Collection::Id id = 123456789012345ll;
+        SentBehaviourAttribute *a = new SentBehaviourAttribute(beh, Collection(id));
+        bool sendSilently = true;
+        a->setSendSilently(sendSilently);
+        QByteArray data = a->serialized();
+        delete a;
+        a = new SentBehaviourAttribute;
+        a->deserialize(data);
+        QCOMPARE(beh, a->sentBehaviour());
+        //When movetodefaultsendCollection we move to -1
+        QCOMPARE(a->moveToCollection().id(), -1);
+        QCOMPARE(sendSilently, a->sendSilently());
+        SentBehaviourAttribute *copy = a->clone();
+        QCOMPARE(copy->sentBehaviour(), beh);
+        //When movetodefaultsendCollection we move to -1
+        QCOMPARE(copy->moveToCollection().id(), -1);
+        QCOMPARE(copy->sendSilently(), sendSilently);
+        delete a;
+        delete copy;
+    }
+
     {
         int id = 3219;
         TransportAttribute *a = new TransportAttribute(id);
